config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
    # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

config etc/mono/browscap.ini.new
config etc/mono/config.new
config etc/mono/mconfig/config.xml.new
config etc/mono/2.0/Browsers/Compat.browser.new
config etc/mono/2.0/DefaultWsdlHelpGenerator.aspx.new
config etc/mono/2.0/machine.config.new
config etc/mono/2.0/settings.map.new
config etc/mono/2.0/web.config.new
config etc/mono/4.0/DefaultWsdlHelpGenerator.aspx.new
config etc/mono/4.0/machine.config.new
config etc/mono/4.0/settings.map.new
config etc/mono/4.0/web.config.new

( cd usr/lib64 ; rm -rf libmono-profiler-cov.so )
( cd usr/lib64 ; ln -sf libmono-profiler-cov.so.0.0.0 libmono-profiler-cov.so )
( cd usr/lib64 ; rm -rf libmono-profiler-iomap.so )
( cd usr/lib64 ; ln -sf libmono-profiler-iomap.so.0.0.0 libmono-profiler-iomap.so )
( cd usr/lib64 ; rm -rf libmono-2.0.so.1 )
( cd usr/lib64 ; ln -sf libmono-2.0.so.1.0.0 libmono-2.0.so.1 )
( cd usr/lib64 ; rm -rf libmonosgen-2.0.so.0 )
( cd usr/lib64 ; ln -sf libmonosgen-2.0.so.0.0.0 libmonosgen-2.0.so.0 )
( cd usr/lib64 ; rm -rf libmonosgen-2.0.so )
( cd usr/lib64 ; ln -sf libmonosgen-2.0.so.0.0.0 libmonosgen-2.0.so )
( cd usr/lib64 ; rm -rf libmono-profiler-log.so )
( cd usr/lib64 ; ln -sf libmono-profiler-log.so.0.0.0 libmono-profiler-log.so )
( cd usr/lib64 ; rm -rf libmono-profiler-aot.so.0 )
( cd usr/lib64 ; ln -sf libmono-profiler-aot.so.0.0.0 libmono-profiler-aot.so.0 )
( cd usr/lib64 ; rm -rf libmono-profiler-cov.so.0 )
( cd usr/lib64 ; ln -sf libmono-profiler-cov.so.0.0.0 libmono-profiler-cov.so.0 )
( cd usr/lib64 ; rm -rf libmono-profiler-log.so.0 )
( cd usr/lib64 ; ln -sf libmono-profiler-log.so.0.0.0 libmono-profiler-log.so.0 )
( cd usr/lib64 ; rm -rf libmono-profiler-aot.so )
( cd usr/lib64 ; ln -sf libmono-profiler-aot.so.0.0.0 libmono-profiler-aot.so )
( cd usr/lib64 ; rm -rf libmono-2.0.so )
( cd usr/lib64 ; ln -sf libmono-2.0.so.1.0.0 libmono-2.0.so )
( cd usr/lib64 ; rm -rf libmono-profiler-iomap.so.0 )
( cd usr/lib64 ; ln -sf libmono-profiler-iomap.so.0.0.0 libmono-profiler-iomap.so.0 )
( cd usr/lib/mono/4.5 ; rm -rf System.Web.Routing.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Web.Routing/4.0.0.0__31bf3856ad364e35/System.Web.Routing.dll System.Web.Routing.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.DirectoryServices.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.DirectoryServices/4.0.0.0__b03f5f7f11d50a3a/System.DirectoryServices.dll System.DirectoryServices.dll )
( cd usr/lib/mono/4.5 ; rm -rf nunit-console-runner.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../2.0/nunit-console-runner.dll nunit-console-runner.dll )
( cd usr/lib/mono/4.5 ; rm -rf nunit.core.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../2.0/nunit.core.dll nunit.core.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Runtime.Serialization.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Runtime.Serialization/4.0.0.0__b77a5c561934e089/System.Runtime.Serialization.dll System.Runtime.Serialization.dll )
( cd usr/lib/mono/4.5 ; rm -rf Microsoft.VisualC.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Microsoft.VisualC/0.0.0.0__b03f5f7f11d50a3a/Microsoft.VisualC.dll Microsoft.VisualC.dll )
( cd usr/lib/mono/4.5 ; rm -rf Mono.Management.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Mono.Management/4.0.0.0__0738eb9f132ed756/Mono.Management.dll Mono.Management.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Transactions.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Transactions/4.0.0.0__b77a5c561934e089/System.Transactions.dll System.Transactions.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Numerics.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Numerics/4.0.0.0__b77a5c561934e089/System.Numerics.dll System.Numerics.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.ServiceModel.Discovery.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.ServiceModel.Discovery/4.0.0.0__31bf3856ad364e35/System.ServiceModel.Discovery.dll System.ServiceModel.Discovery.dll )
( cd usr/lib/mono/4.5 ; rm -rf Mono.Simd.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Mono.Simd/4.0.0.0__0738eb9f132ed756/Mono.Simd.dll Mono.Simd.dll )
( cd usr/lib/mono/4.5 ; rm -rf CustomMarshalers.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/CustomMarshalers/4.0.0.0__b03f5f7f11d50a3a/CustomMarshalers.dll CustomMarshalers.dll )
( cd usr/lib/mono/4.5 ; rm -rf Mono.CompilerServices.SymbolWriter.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Mono.CompilerServices.SymbolWriter/4.0.0.0__0738eb9f132ed756/Mono.CompilerServices.SymbolWriter.dll Mono.CompilerServices.SymbolWriter.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Windows.Forms.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Windows.Forms/4.0.0.0__b77a5c561934e089/System.Windows.Forms.dll System.Windows.Forms.dll )
( cd usr/lib/mono/4.5 ; rm -rf I18N.West.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/I18N.West/4.0.0.0__0738eb9f132ed756/I18N.West.dll I18N.West.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Configuration.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Configuration/4.0.0.0__b03f5f7f11d50a3a/System.Configuration.dll System.Configuration.dll )
( cd usr/lib/mono/4.5 ; rm -rf OpenSystem.C.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/OpenSystem.C/4.0.0.0__b77a5c561934e089/OpenSystem.C.dll OpenSystem.C.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Web.Http.SelfHost.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Web.Http.SelfHost/4.0.0.0__31bf3856ad364e35/System.Web.Http.SelfHost.dll System.Web.Http.SelfHost.dll )
( cd usr/lib/mono/4.5 ; rm -rf Microsoft.Build.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Microsoft.Build/4.0.0.0__b03f5f7f11d50a3a/Microsoft.Build.dll Microsoft.Build.dll )
( cd usr/lib/mono/4.5 ; rm -rf I18N.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/I18N/4.0.0.0__0738eb9f132ed756/I18N.dll I18N.dll )
( cd usr/lib/mono/4.5 ; rm -rf Mono.Cairo.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Mono.Cairo/4.0.0.0__0738eb9f132ed756/Mono.Cairo.dll Mono.Cairo.dll )
( cd usr/lib/mono/4.5 ; rm -rf Microsoft.Build.Utilities.v4.0.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Microsoft.Build.Utilities.v4.0/4.0.0.0__b03f5f7f11d50a3a/Microsoft.Build.Utilities.v4.0.dll Microsoft.Build.Utilities.v4.0.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Xml.Linq.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Xml.Linq/4.0.0.0__b77a5c561934e089/System.Xml.Linq.dll System.Xml.Linq.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Runtime.Remoting.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Runtime.Remoting/4.0.0.0__b77a5c561934e089/System.Runtime.Remoting.dll System.Runtime.Remoting.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.ServiceModel.Web.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.ServiceModel.Web/4.0.0.0__31bf3856ad364e35/System.ServiceModel.Web.dll System.ServiceModel.Web.dll )
( cd usr/lib/mono/4.5 ; rm -rf ICSharpCode.SharpZipLib.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/ICSharpCode.SharpZipLib/4.84.0.0__1b03e6acf1164f73/ICSharpCode.SharpZipLib.dll ICSharpCode.SharpZipLib.dll )
( cd usr/lib/mono/4.5 ; rm -rf nunit.core.interfaces.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../2.0/nunit.core.interfaces.dll nunit.core.interfaces.dll )
( cd usr/lib/mono/4.5 ; rm -rf I18N.Other.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/I18N.Other/4.0.0.0__0738eb9f132ed756/I18N.Other.dll I18N.Other.dll )
( cd usr/lib/mono/4.5 ; rm -rf EntityFramework.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/EntityFramework/6.0.0.0__b77a5c561934e089/EntityFramework.dll EntityFramework.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Web.ApplicationServices.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Web.ApplicationServices/4.0.0.0__31bf3856ad364e35/System.Web.ApplicationServices.dll System.Web.ApplicationServices.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System/4.0.0.0__b77a5c561934e089/System.dll System.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Web.Abstractions.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Web.Abstractions/4.0.0.0__31bf3856ad364e35/System.Web.Abstractions.dll System.Web.Abstractions.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Net.Http.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Net.Http/4.0.0.0__b03f5f7f11d50a3a/System.Net.Http.dll System.Net.Http.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Windows.Forms.DataVisualization.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Windows.Forms.DataVisualization/4.0.0.0__b77a5c561934e089/System.Windows.Forms.DataVisualization.dll System.Windows.Forms.DataVisualization.dll )
( cd usr/lib/mono/4.5 ; rm -rf nunit.framework.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../2.0/nunit.framework.dll nunit.framework.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Data.Services.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Data.Services/4.0.0.0__b77a5c561934e089/System.Data.Services.dll System.Data.Services.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Runtime.Serialization.Formatters.Soap.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Runtime.Serialization.Formatters.Soap/4.0.0.0__b03f5f7f11d50a3a/System.Runtime.Serialization.Formatters.Soap.dll System.Runtime.Serialization.Formatters.Soap.dll )
( cd usr/lib/mono/4.5 ; rm -rf Mono.Tasklets.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Mono.Tasklets/4.0.0.0__0738eb9f132ed756/Mono.Tasklets.dll Mono.Tasklets.dll )
( cd usr/lib/mono/4.5 ; rm -rf Mono.CodeContracts.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Mono.CodeContracts/4.0.0.0__0738eb9f132ed756/Mono.CodeContracts.dll Mono.CodeContracts.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.ServiceModel.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.ServiceModel/4.0.0.0__b77a5c561934e089/System.ServiceModel.dll System.ServiceModel.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Web.Extensions.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Web.Extensions/4.0.0.0__31bf3856ad364e35/System.Web.Extensions.dll System.Web.Extensions.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Data.Services.Client.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Data.Services.Client/4.0.0.0__b77a5c561934e089/System.Data.Services.Client.dll System.Data.Services.Client.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.ComponentModel.Composition.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.ComponentModel.Composition/4.0.0.0__b77a5c561934e089/System.ComponentModel.Composition.dll System.ComponentModel.Composition.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Threading.Tasks.Dataflow.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Threading.Tasks.Dataflow/4.0.0.0__b77a5c561934e089/System.Threading.Tasks.Dataflow.dll System.Threading.Tasks.Dataflow.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Web.DynamicData.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Web.DynamicData/4.0.0.0__31bf3856ad364e35/System.Web.DynamicData.dll System.Web.DynamicData.dll )
( cd usr/lib/mono/4.5 ; rm -rf nunit.mocks.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../2.0/nunit.mocks.dll nunit.mocks.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.EnterpriseServices.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.EnterpriseServices/4.0.0.0__b03f5f7f11d50a3a/System.EnterpriseServices.dll System.EnterpriseServices.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Drawing.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Drawing/4.0.0.0__b03f5f7f11d50a3a/System.Drawing.dll System.Drawing.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Xaml.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Xaml/4.0.0.0__b77a5c561934e089/System.Xaml.dll System.Xaml.dll )
( cd usr/lib/mono/4.5 ; rm -rf Commons.Xml.Relaxng.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Commons.Xml.Relaxng/4.0.0.0__0738eb9f132ed756/Commons.Xml.Relaxng.dll Commons.Xml.Relaxng.dll )
( cd usr/lib/mono/4.5 ; rm -rf I18N.CJK.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/I18N.CJK/4.0.0.0__0738eb9f132ed756/I18N.CJK.dll I18N.CJK.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Xml.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Xml/4.0.0.0__b77a5c561934e089/System.Xml.dll System.Xml.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Web.WebPages.Deployment.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Web.WebPages.Deployment/2.0.0.0__31bf3856ad364e35/System.Web.WebPages.Deployment.dll System.Web.WebPages.Deployment.dll )
( cd usr/lib/mono/4.5 ; rm -rf Mono.Http.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Mono.Http/4.0.0.0__0738eb9f132ed756/Mono.Http.dll Mono.Http.dll )
( cd usr/lib/mono/4.5 ; rm -rf Mono.WebBrowser.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Mono.WebBrowser/4.0.0.0__0738eb9f132ed756/Mono.WebBrowser.dll Mono.WebBrowser.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Web.WebPages.Razor.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Web.WebPages.Razor/2.0.0.0__31bf3856ad364e35/System.Web.WebPages.Razor.dll System.Web.WebPages.Razor.dll )
( cd usr/lib/mono/4.5 ; rm -rf PEAPI.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/PEAPI/4.0.0.0__0738eb9f132ed756/PEAPI.dll PEAPI.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Web.WebPages.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Web.WebPages/2.0.0.0__31bf3856ad364e35/System.Web.WebPages.dll System.Web.WebPages.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Web.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Web/4.0.0.0__b03f5f7f11d50a3a/System.Web.dll System.Web.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Messaging.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Messaging/4.0.0.0__b03f5f7f11d50a3a/System.Messaging.dll System.Messaging.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Net.Http.Formatting.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Net.Http.Formatting/4.0.0.0__31bf3856ad364e35/System.Net.Http.Formatting.dll System.Net.Http.Formatting.dll )
( cd usr/lib/mono/4.5 ; rm -rf Mono.Debugger.Soft.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Mono.Debugger.Soft/4.0.0.0__0738eb9f132ed756/Mono.Debugger.Soft.dll Mono.Debugger.Soft.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Runtime.Caching.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Runtime.Caching/4.0.0.0__b03f5f7f11d50a3a/System.Runtime.Caching.dll System.Runtime.Caching.dll )
( cd usr/lib/mono/4.5 ; rm -rf Microsoft.CSharp.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Microsoft.CSharp/4.0.0.0__b03f5f7f11d50a3a/Microsoft.CSharp.dll Microsoft.CSharp.dll )
( cd usr/lib/mono/4.5 ; rm -rf WindowsBase.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/WindowsBase/4.0.0.0__31bf3856ad364e35/WindowsBase.dll WindowsBase.dll )
( cd usr/lib/mono/4.5 ; rm -rf I18N.MidEast.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/I18N.MidEast/4.0.0.0__0738eb9f132ed756/I18N.MidEast.dll I18N.MidEast.dll )
( cd usr/lib/mono/4.5 ; rm -rf cscompmgd.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/cscompmgd/0.0.0.0__b03f5f7f11d50a3a/cscompmgd.dll cscompmgd.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Web.Razor.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Web.Razor/2.0.0.0__31bf3856ad364e35/System.Web.Razor.dll System.Web.Razor.dll )
( cd usr/lib/mono/4.5 ; rm -rf Mono.Data.Tds.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Mono.Data.Tds/4.0.0.0__0738eb9f132ed756/Mono.Data.Tds.dll Mono.Data.Tds.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Data.DataSetExtensions.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Data.DataSetExtensions/4.0.0.0__b77a5c561934e089/System.Data.DataSetExtensions.dll System.Data.DataSetExtensions.dll )
( cd usr/lib/mono/4.5 ; rm -rf IBM.Data.DB2.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/IBM.Data.DB2/1.0.0.0__7c307b91aa13d208/IBM.Data.DB2.dll IBM.Data.DB2.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Security.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Security/4.0.0.0__b03f5f7f11d50a3a/System.Security.dll System.Security.dll )
( cd usr/lib/mono/4.5 ; rm -rf Mono.C5.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Mono.C5/1.1.1.0__ba07f434b1c35cbd/Mono.C5.dll Mono.C5.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.ServiceProcess.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.ServiceProcess/4.0.0.0__b03f5f7f11d50a3a/System.ServiceProcess.dll System.ServiceProcess.dll )
( cd usr/lib/mono/4.5 ; rm -rf Mono.Posix.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Mono.Posix/4.0.0.0__0738eb9f132ed756/Mono.Posix.dll Mono.Posix.dll )
( cd usr/lib/mono/4.5 ; rm -rf Mono.Data.Sqlite.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Mono.Data.Sqlite/4.0.0.0__0738eb9f132ed756/Mono.Data.Sqlite.dll Mono.Data.Sqlite.dll )
( cd usr/lib/mono/4.5 ; rm -rf Mono.Messaging.RabbitMQ.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Mono.Messaging.RabbitMQ/4.0.0.0__0738eb9f132ed756/Mono.Messaging.RabbitMQ.dll Mono.Messaging.RabbitMQ.dll )
( cd usr/lib/mono/4.5 ; rm -rf WebMatrix.Data.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/WebMatrix.Data/4.0.0.0__0738eb9f132ed756/WebMatrix.Data.dll WebMatrix.Data.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Dynamic.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Dynamic/4.0.0.0__b77a5c561934e089/System.Dynamic.dll System.Dynamic.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Management.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Management/4.0.0.0__b03f5f7f11d50a3a/System.Management.dll System.Management.dll )
( cd usr/lib/mono/4.5 ; rm -rf Npgsql.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Npgsql/4.0.0.0__5d8b90d52f46fda7/Npgsql.dll Npgsql.dll )
( cd usr/lib/mono/4.5 ; rm -rf Mono.Security.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Mono.Security/4.0.0.0__0738eb9f132ed756/Mono.Security.dll Mono.Security.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Configuration.Install.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Configuration.Install/4.0.0.0__b03f5f7f11d50a3a/System.Configuration.Install.dll System.Configuration.Install.dll )
( cd usr/lib/mono/4.5 ; rm -rf nunit.util.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../2.0/nunit.util.dll nunit.util.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.IdentityModel.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.IdentityModel/4.0.0.0__b77a5c561934e089/System.IdentityModel.dll System.IdentityModel.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Data.Linq.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Data.Linq/4.0.0.0__b77a5c561934e089/System.Data.Linq.dll System.Data.Linq.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Net.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Net/4.0.0.0__7cec85d7bea7798e/System.Net.dll System.Net.dll )
( cd usr/lib/mono/4.5 ; rm -rf I18N.Rare.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/I18N.Rare/4.0.0.0__0738eb9f132ed756/I18N.Rare.dll I18N.Rare.dll )
( cd usr/lib/mono/4.5 ; rm -rf Microsoft.Build.Engine.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Microsoft.Build.Engine/4.0.0.0__b03f5f7f11d50a3a/Microsoft.Build.Engine.dll Microsoft.Build.Engine.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.ServiceModel.Routing.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.ServiceModel.Routing/4.0.0.0__31bf3856ad364e35/System.ServiceModel.Routing.dll System.ServiceModel.Routing.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Runtime.DurableInstancing.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Runtime.DurableInstancing/4.0.0.0__31bf3856ad364e35/System.Runtime.DurableInstancing.dll System.Runtime.DurableInstancing.dll )
( cd usr/lib/mono/4.5 ; rm -rf Microsoft.Web.Infrastructure.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Microsoft.Web.Infrastructure/1.0.0.0__31bf3856ad364e35/Microsoft.Web.Infrastructure.dll Microsoft.Web.Infrastructure.dll )
( cd usr/lib/mono/4.5 ; rm -rf Mono.CSharp.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Mono.CSharp/4.0.0.0__0738eb9f132ed756/Mono.CSharp.dll Mono.CSharp.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Core.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Core/4.0.0.0__b77a5c561934e089/System.Core.dll System.Core.dll )
( cd usr/lib/mono/4.5 ; rm -rf Microsoft.Build.Framework.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Microsoft.Build.Framework/4.0.0.0__b03f5f7f11d50a3a/Microsoft.Build.Framework.dll Microsoft.Build.Framework.dll )
( cd usr/lib/mono/4.5 ; rm -rf nunit.core.extensions.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../2.0/nunit.core.extensions.dll nunit.core.extensions.dll )
( cd usr/lib/mono/4.5 ; rm -rf Novell.Directory.Ldap.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Novell.Directory.Ldap/4.0.0.0__0738eb9f132ed756/Novell.Directory.Ldap.dll Novell.Directory.Ldap.dll )
( cd usr/lib/mono/4.5 ; rm -rf Mono.Security.Win32.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Mono.Security.Win32/4.0.0.0__0738eb9f132ed756/Mono.Security.Win32.dll Mono.Security.Win32.dll )
( cd usr/lib/mono/4.5 ; rm -rf Mono.Web.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Mono.Web/4.0.0.0__0738eb9f132ed756/Mono.Web.dll Mono.Web.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Json.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Json/4.0.0.0__31bf3856ad364e35/System.Json.dll System.Json.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Data.OracleClient.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Data.OracleClient/4.0.0.0__b77a5c561934e089/System.Data.OracleClient.dll System.Data.OracleClient.dll )
( cd usr/lib/mono/4.5 ; rm -rf Microsoft.Build.Tasks.v4.0.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Microsoft.Build.Tasks.v4.0/4.0.0.0__b03f5f7f11d50a3a/Microsoft.Build.Tasks.v4.0.dll Microsoft.Build.Tasks.v4.0.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Data.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Data/4.0.0.0__b77a5c561934e089/System.Data.dll System.Data.dll )
( cd usr/lib/mono/4.5 ; rm -rf RabbitMQ.Client.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/RabbitMQ.Client/4.0.0.0__b03f5f7f11d50a3a/RabbitMQ.Client.dll RabbitMQ.Client.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Drawing.Design.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Drawing.Design/4.0.0.0__b03f5f7f11d50a3a/System.Drawing.Design.dll System.Drawing.Design.dll )
( cd usr/lib/mono/4.5 ; rm -rf Mono.Parallel.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Mono.Parallel/4.0.0.0__0738eb9f132ed756/Mono.Parallel.dll Mono.Parallel.dll )
( cd usr/lib/mono/4.5 ; rm -rf Mono.Messaging.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Mono.Messaging/4.0.0.0__0738eb9f132ed756/Mono.Messaging.dll Mono.Messaging.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Web.Services.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Web.Services/4.0.0.0__b03f5f7f11d50a3a/System.Web.Services.dll System.Web.Services.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.IdentityModel.Selectors.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.IdentityModel.Selectors/4.0.0.0__b77a5c561934e089/System.IdentityModel.Selectors.dll System.IdentityModel.Selectors.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Web.Mvc.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Web.Mvc/3.0.0.0__31bf3856ad364e35/System.Web.Mvc.dll System.Web.Mvc.dll )
( cd usr/lib/mono/4.5 ; rm -rf Accessibility.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/Accessibility/4.0.0.0__b03f5f7f11d50a3a/Accessibility.dll Accessibility.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Design.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Design/4.0.0.0__b03f5f7f11d50a3a/System.Design.dll System.Design.dll )
( cd usr/lib/mono/4.5 ; rm -rf EntityFramework.SqlServer.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/EntityFramework.SqlServer/6.0.0.0__b77a5c561934e089/EntityFramework.SqlServer.dll EntityFramework.SqlServer.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.ComponentModel.DataAnnotations.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.ComponentModel.DataAnnotations/4.0.0.0__31bf3856ad364e35/System.ComponentModel.DataAnnotations.dll System.ComponentModel.DataAnnotations.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Web.Extensions.Design.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Web.Extensions.Design/4.0.0.0__31bf3856ad364e35/System.Web.Extensions.Design.dll System.Web.Extensions.Design.dll )
( cd usr/lib/mono/4.5 ; rm -rf nunit.framework.extensions.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../2.0/nunit.framework.extensions.dll nunit.framework.extensions.dll )
( cd usr/lib/mono/4.5 ; rm -rf System.Web.Http.dll )
( cd usr/lib/mono/4.5 ; ln -sf ../gac/System.Web.Http/4.0.0.0__31bf3856ad364e35/System.Web.Http.dll System.Web.Http.dll )
( cd usr/lib/mono/compat-2.0 ; rm -rf ICSharpCode.SharpZipLib.dll )
( cd usr/lib/mono/compat-2.0 ; ln -sf ../gac/ICSharpCode.SharpZipLib/2.6.0.0__1b03e6acf1164f73/ICSharpCode.SharpZipLib.dll ICSharpCode.SharpZipLib.dll )
( cd usr/lib/mono/compat-2.0 ; rm -rf System.Web.Extensions.dll )
( cd usr/lib/mono/compat-2.0 ; ln -sf ../gac/System.Web.Extensions/1.0.61025.0__31bf3856ad364e35/System.Web.Extensions.dll System.Web.Extensions.dll )
( cd usr/lib/mono/compat-2.0 ; rm -rf System.Web.Mvc.dll )
( cd usr/lib/mono/compat-2.0 ; ln -sf ../gac/System.Web.Mvc/1.0.0.0__31bf3856ad364e35/System.Web.Mvc.dll System.Web.Mvc.dll )
( cd usr/lib/mono/compat-2.0 ; rm -rf System.Web.Extensions.Design.dll )
( cd usr/lib/mono/compat-2.0 ; ln -sf ../gac/System.Web.Extensions.Design/1.0.61025.0__31bf3856ad364e35/System.Web.Extensions.Design.dll System.Web.Extensions.Design.dll )
( cd usr/lib/mono/3.5 ; rm -rf Microsoft.Build.Utilities.v3.5.dll )
( cd usr/lib/mono/3.5 ; ln -sf ../gac/Microsoft.Build.Utilities.v3.5/3.5.0.0__b03f5f7f11d50a3a/Microsoft.Build.Utilities.v3.5.dll Microsoft.Build.Utilities.v3.5.dll )
( cd usr/lib/mono/3.5 ; rm -rf Microsoft.Build.Tasks.v3.5.dll )
( cd usr/lib/mono/3.5 ; ln -sf ../gac/Microsoft.Build.Tasks.v3.5/3.5.0.0__b03f5f7f11d50a3a/Microsoft.Build.Tasks.v3.5.dll Microsoft.Build.Tasks.v3.5.dll )
( cd usr/lib/mono/3.5 ; rm -rf Microsoft.Build.Engine.dll )
( cd usr/lib/mono/3.5 ; ln -sf ../gac/Microsoft.Build.Engine/3.5.0.0__b03f5f7f11d50a3a/Microsoft.Build.Engine.dll Microsoft.Build.Engine.dll )
( cd usr/lib/mono/3.5 ; rm -rf Microsoft.Build.Framework.dll )
( cd usr/lib/mono/3.5 ; ln -sf ../gac/Microsoft.Build.Framework/3.5.0.0__b03f5f7f11d50a3a/Microsoft.Build.Framework.dll Microsoft.Build.Framework.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Web.Routing.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Web.Routing/3.5.0.0__31bf3856ad364e35/System.Web.Routing.dll System.Web.Routing.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.DirectoryServices.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.DirectoryServices/2.0.0.0__b03f5f7f11d50a3a/System.DirectoryServices.dll System.DirectoryServices.dll )
( cd usr/lib/mono/2.0 ; rm -rf nunit-console-runner.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/nunit-console-runner/2.4.8.0__96d09a1eb7f44a77/nunit-console-runner.dll nunit-console-runner.dll )
( cd usr/lib/mono/2.0 ; rm -rf nunit.core.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/nunit.core/2.4.8.0__96d09a1eb7f44a77/nunit.core.dll nunit.core.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Runtime.Serialization.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Runtime.Serialization/3.0.0.0__b77a5c561934e089/System.Runtime.Serialization.dll System.Runtime.Serialization.dll )
( cd usr/lib/mono/2.0 ; rm -rf Microsoft.VisualC.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Microsoft.VisualC/8.0.0.0__b03f5f7f11d50a3a/Microsoft.VisualC.dll Microsoft.VisualC.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.Management.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.Management/2.0.0.0__0738eb9f132ed756/Mono.Management.dll Mono.Management.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Transactions.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Transactions/2.0.0.0__b77a5c561934e089/System.Transactions.dll System.Transactions.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.Simd.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.Simd/2.0.0.0__0738eb9f132ed756/Mono.Simd.dll Mono.Simd.dll )
( cd usr/lib/mono/2.0 ; rm -rf CustomMarshalers.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/CustomMarshalers/2.0.0.0__b03f5f7f11d50a3a/CustomMarshalers.dll CustomMarshalers.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.CompilerServices.SymbolWriter.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.CompilerServices.SymbolWriter/2.0.0.0__0738eb9f132ed756/Mono.CompilerServices.SymbolWriter.dll Mono.CompilerServices.SymbolWriter.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Windows.Forms.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Windows.Forms/2.0.0.0__b77a5c561934e089/System.Windows.Forms.dll System.Windows.Forms.dll )
( cd usr/lib/mono/2.0 ; rm -rf I18N.West.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/I18N.West/2.0.0.0__0738eb9f132ed756/I18N.West.dll I18N.West.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Configuration.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Configuration/2.0.0.0__b03f5f7f11d50a3a/System.Configuration.dll System.Configuration.dll )
( cd usr/lib/mono/2.0 ; rm -rf OpenSystem.C.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/OpenSystem.C/2.0.0.0__b77a5c561934e089/OpenSystem.C.dll OpenSystem.C.dll )
( cd usr/lib/mono/2.0 ; rm -rf I18N.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/I18N/2.0.0.0__0738eb9f132ed756/I18N.dll I18N.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.Cairo.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.Cairo/2.0.0.0__0738eb9f132ed756/Mono.Cairo.dll Mono.Cairo.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Xml.Linq.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Xml.Linq/3.5.0.0__b77a5c561934e089/System.Xml.Linq.dll System.Xml.Linq.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Runtime.Remoting.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Runtime.Remoting/2.0.0.0__b77a5c561934e089/System.Runtime.Remoting.dll System.Runtime.Remoting.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.ServiceModel.Web.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.ServiceModel.Web/3.5.0.0__31bf3856ad364e35/System.ServiceModel.Web.dll System.ServiceModel.Web.dll )
( cd usr/lib/mono/2.0 ; rm -rf ICSharpCode.SharpZipLib.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/ICSharpCode.SharpZipLib/2.84.0.0__1b03e6acf1164f73/ICSharpCode.SharpZipLib.dll ICSharpCode.SharpZipLib.dll )
( cd usr/lib/mono/2.0 ; rm -rf nunit.core.interfaces.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/nunit.core.interfaces/2.4.8.0__96d09a1eb7f44a77/nunit.core.interfaces.dll nunit.core.interfaces.dll )
( cd usr/lib/mono/2.0 ; rm -rf I18N.Other.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/I18N.Other/2.0.0.0__0738eb9f132ed756/I18N.Other.dll I18N.Other.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System/2.0.0.0__b77a5c561934e089/System.dll System.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Web.Abstractions.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Web.Abstractions/3.5.0.0__31bf3856ad364e35/System.Web.Abstractions.dll System.Web.Abstractions.dll )
( cd usr/lib/mono/2.0 ; rm -rf nunit.framework.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/nunit.framework/2.4.8.0__96d09a1eb7f44a77/nunit.framework.dll nunit.framework.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Data.Services.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Data.Services/3.5.0.0__b77a5c561934e089/System.Data.Services.dll System.Data.Services.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Runtime.Serialization.Formatters.Soap.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Runtime.Serialization.Formatters.Soap/2.0.0.0__b03f5f7f11d50a3a/System.Runtime.Serialization.Formatters.Soap.dll System.Runtime.Serialization.Formatters.Soap.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.Tasklets.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.Tasklets/2.0.0.0__0738eb9f132ed756/Mono.Tasklets.dll Mono.Tasklets.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.ServiceModel.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.ServiceModel/3.0.0.0__b77a5c561934e089/System.ServiceModel.dll System.ServiceModel.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Web.Extensions.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Web.Extensions/3.5.0.0__31bf3856ad364e35/System.Web.Extensions.dll System.Web.Extensions.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Data.Services.Client.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Data.Services.Client/3.5.0.0__b77a5c561934e089/System.Data.Services.Client.dll System.Data.Services.Client.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Web.DynamicData.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Web.DynamicData/3.5.0.0__31bf3856ad364e35/System.Web.DynamicData.dll System.Web.DynamicData.dll )
( cd usr/lib/mono/2.0 ; rm -rf nunit.mocks.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/nunit.mocks/2.4.8.0__96d09a1eb7f44a77/nunit.mocks.dll nunit.mocks.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.EnterpriseServices.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.EnterpriseServices/2.0.0.0__b03f5f7f11d50a3a/System.EnterpriseServices.dll System.EnterpriseServices.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Drawing.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Drawing/2.0.0.0__b03f5f7f11d50a3a/System.Drawing.dll System.Drawing.dll )
( cd usr/lib/mono/2.0 ; rm -rf Microsoft.Build.Utilities.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Microsoft.Build.Utilities/2.0.0.0__b03f5f7f11d50a3a/Microsoft.Build.Utilities.dll Microsoft.Build.Utilities.dll )
( cd usr/lib/mono/2.0 ; rm -rf Commons.Xml.Relaxng.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Commons.Xml.Relaxng/2.0.0.0__0738eb9f132ed756/Commons.Xml.Relaxng.dll Commons.Xml.Relaxng.dll )
( cd usr/lib/mono/2.0 ; rm -rf I18N.CJK.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/I18N.CJK/2.0.0.0__0738eb9f132ed756/I18N.CJK.dll I18N.CJK.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Xml.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Xml/2.0.0.0__b77a5c561934e089/System.Xml.dll System.Xml.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.Http.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.Http/2.0.0.0__0738eb9f132ed756/Mono.Http.dll Mono.Http.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.WebBrowser.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.WebBrowser/2.0.0.0__0738eb9f132ed756/Mono.WebBrowser.dll Mono.WebBrowser.dll )
( cd usr/lib/mono/2.0 ; rm -rf PEAPI.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/PEAPI/2.0.0.0__0738eb9f132ed756/PEAPI.dll PEAPI.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Web.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Web/2.0.0.0__b03f5f7f11d50a3a/System.Web.dll System.Web.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Messaging.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Messaging/2.0.0.0__b03f5f7f11d50a3a/System.Messaging.dll System.Messaging.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.Debugger.Soft.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.Debugger.Soft/2.0.0.0__0738eb9f132ed756/Mono.Debugger.Soft.dll Mono.Debugger.Soft.dll )
( cd usr/lib/mono/2.0 ; rm -rf WindowsBase.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/WindowsBase/3.0.0.0__31bf3856ad364e35/WindowsBase.dll WindowsBase.dll )
( cd usr/lib/mono/2.0 ; rm -rf I18N.MidEast.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/I18N.MidEast/2.0.0.0__0738eb9f132ed756/I18N.MidEast.dll I18N.MidEast.dll )
( cd usr/lib/mono/2.0 ; rm -rf cscompmgd.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/cscompmgd/8.0.0.0__b03f5f7f11d50a3a/cscompmgd.dll cscompmgd.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.Data.Tds.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.Data.Tds/2.0.0.0__0738eb9f132ed756/Mono.Data.Tds.dll Mono.Data.Tds.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Data.DataSetExtensions.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Data.DataSetExtensions/3.5.0.0__b77a5c561934e089/System.Data.DataSetExtensions.dll System.Data.DataSetExtensions.dll )
( cd usr/lib/mono/2.0 ; rm -rf IBM.Data.DB2.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/IBM.Data.DB2/1.0.0.0__7c307b91aa13d208/IBM.Data.DB2.dll IBM.Data.DB2.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Security.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Security/2.0.0.0__b03f5f7f11d50a3a/System.Security.dll System.Security.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.C5.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.C5/1.1.1.0__ba07f434b1c35cbd/Mono.C5.dll Mono.C5.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.ServiceProcess.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.ServiceProcess/2.0.0.0__b03f5f7f11d50a3a/System.ServiceProcess.dll System.ServiceProcess.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.Posix.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.Posix/2.0.0.0__0738eb9f132ed756/Mono.Posix.dll Mono.Posix.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.Data.Sqlite.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.Data.Sqlite/2.0.0.0__0738eb9f132ed756/Mono.Data.Sqlite.dll Mono.Data.Sqlite.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.Messaging.RabbitMQ.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.Messaging.RabbitMQ/2.0.0.0__0738eb9f132ed756/Mono.Messaging.RabbitMQ.dll Mono.Messaging.RabbitMQ.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Management.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Management/2.0.0.0__b03f5f7f11d50a3a/System.Management.dll System.Management.dll )
( cd usr/lib/mono/2.0 ; rm -rf Npgsql.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Npgsql/2.0.0.0__5d8b90d52f46fda7/Npgsql.dll Npgsql.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.Security.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.Security/2.0.0.0__0738eb9f132ed756/Mono.Security.dll Mono.Security.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Configuration.Install.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Configuration.Install/2.0.0.0__b03f5f7f11d50a3a/System.Configuration.Install.dll System.Configuration.Install.dll )
( cd usr/lib/mono/2.0 ; rm -rf nunit.util.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/nunit.util/2.4.8.0__96d09a1eb7f44a77/nunit.util.dll nunit.util.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.IdentityModel.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.IdentityModel/3.0.0.0__b77a5c561934e089/System.IdentityModel.dll System.IdentityModel.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Data.Linq.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Data.Linq/3.5.0.0__b77a5c561934e089/System.Data.Linq.dll System.Data.Linq.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Net.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Net/3.5.0.0__7cec85d7bea7798e/System.Net.dll System.Net.dll )
( cd usr/lib/mono/2.0 ; rm -rf I18N.Rare.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/I18N.Rare/2.0.0.0__0738eb9f132ed756/I18N.Rare.dll I18N.Rare.dll )
( cd usr/lib/mono/2.0 ; rm -rf Microsoft.Build.Engine.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Microsoft.Build.Engine/2.0.0.0__b03f5f7f11d50a3a/Microsoft.Build.Engine.dll Microsoft.Build.Engine.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.CSharp.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.CSharp/2.0.0.0__0738eb9f132ed756/Mono.CSharp.dll Mono.CSharp.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Core.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Core/3.5.0.0__b77a5c561934e089/System.Core.dll System.Core.dll )
( cd usr/lib/mono/2.0 ; rm -rf Microsoft.Build.Framework.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Microsoft.Build.Framework/2.0.0.0__b03f5f7f11d50a3a/Microsoft.Build.Framework.dll Microsoft.Build.Framework.dll )
( cd usr/lib/mono/2.0 ; rm -rf nunit.core.extensions.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/nunit.core.extensions/2.4.8.0__96d09a1eb7f44a77/nunit.core.extensions.dll nunit.core.extensions.dll )
( cd usr/lib/mono/2.0 ; rm -rf Novell.Directory.Ldap.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Novell.Directory.Ldap/2.0.0.0__0738eb9f132ed756/Novell.Directory.Ldap.dll Novell.Directory.Ldap.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.Security.Win32.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.Security.Win32/2.0.0.0__0738eb9f132ed756/Mono.Security.Win32.dll Mono.Security.Win32.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.Web.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.Web/2.0.0.0__0738eb9f132ed756/Mono.Web.dll Mono.Web.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Data.OracleClient.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Data.OracleClient/2.0.0.0__b77a5c561934e089/System.Data.OracleClient.dll System.Data.OracleClient.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Data.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Data/2.0.0.0__b77a5c561934e089/System.Data.dll System.Data.dll )
( cd usr/lib/mono/2.0 ; rm -rf RabbitMQ.Client.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/RabbitMQ.Client/2.0.0.0__b03f5f7f11d50a3a/RabbitMQ.Client.dll RabbitMQ.Client.dll )
( cd usr/lib/mono/2.0 ; rm -rf Microsoft.Build.Tasks.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Microsoft.Build.Tasks/2.0.0.0__b03f5f7f11d50a3a/Microsoft.Build.Tasks.dll Microsoft.Build.Tasks.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Drawing.Design.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Drawing.Design/2.0.0.0__b03f5f7f11d50a3a/System.Drawing.Design.dll System.Drawing.Design.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.Messaging.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.Messaging/2.0.0.0__0738eb9f132ed756/Mono.Messaging.dll Mono.Messaging.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Web.Services.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Web.Services/2.0.0.0__b03f5f7f11d50a3a/System.Web.Services.dll System.Web.Services.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.IdentityModel.Selectors.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.IdentityModel.Selectors/3.0.0.0__b77a5c561934e089/System.IdentityModel.Selectors.dll System.IdentityModel.Selectors.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Web.Mvc.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Web.Mvc/2.0.0.0__31bf3856ad364e35/System.Web.Mvc.dll System.Web.Mvc.dll )
( cd usr/lib/mono/2.0 ; rm -rf Accessibility.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Accessibility/2.0.0.0__b03f5f7f11d50a3a/Accessibility.dll Accessibility.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Design.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Design/2.0.0.0__b03f5f7f11d50a3a/System.Design.dll System.Design.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.ComponentModel.DataAnnotations.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.ComponentModel.DataAnnotations/3.5.0.0__31bf3856ad364e35/System.ComponentModel.DataAnnotations.dll System.ComponentModel.DataAnnotations.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Web.Extensions.Design.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Web.Extensions.Design/3.5.0.0__31bf3856ad364e35/System.Web.Extensions.Design.dll System.Web.Extensions.Design.dll )
( cd usr/lib/mono/2.0 ; rm -rf nunit.framework.extensions.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/nunit.framework.extensions/2.4.8.0__96d09a1eb7f44a77/nunit.framework.extensions.dll nunit.framework.extensions.dll )
( cd usr/lib/mono/monodoc ; rm -rf monodoc.dll )
( cd usr/lib/mono/monodoc ; ln -sf ../gac/monodoc/1.0.0.0__0738eb9f132ed756/monodoc.dll monodoc.dll )
